@@ -93,23 +93,25 @@ get_data_by_unit_locality <- function(unitId, varId, year = NULL,
       colname <- paste0("attrId_", x, sep = "")
       names(temp)[names(temp) == "attrId"] <- colname
       
-      if(type == "label"){
-         colname <- paste0("attributeDescription_", x, sep = "")
-         names(temp)[names(temp) == "attributeDescription"] <- colname
-      }else{
-         temp <- dplyr::select(temp,-dplyr::one_of(c("attributeDescription")))
-      }
+
+      colname <- paste0("attributeDescription_", x, sep = "")
+      names(temp)[names(temp) == "attributeDescription"] <- colname
       
       temp
    }
    
    df <- lapply(unitId, helper)
    df <- df[lengths(df) != 0]
-   df <- purrr::reduce(df, dplyr::left_join)
-   df <- df %>% select(one_of("id", "year"), starts_with("val"), 
-                       starts_with("measure"), starts_with("attr"),everything())
+   if(length(df) > 0){
+      df <- purrr::reduce(df, dplyr::left_join)
+   } else {
+      stop("Filters returned empty set for every unit you provided.")
+   }
+  
 
  }
+ df <- df %>% select(one_of("id", "year"), starts_with("val"), 
+                     starts_with("measure"), starts_with("attr"),everything())
  
  if (type == "label") {
    variables <- unique(df$id)
