@@ -52,6 +52,7 @@ get_data_by_variable_locality <- function(varId, unitParentId, year = NULL,
     
     df <- page_download(dir, varId, filters, ...)
     df <- add_attribute_labels(df, lang)
+    df <- add_measure_columns(varId, df, lang)
     
   } else {
     varId <- as.list(varId)
@@ -70,6 +71,12 @@ get_data_by_variable_locality <- function(varId, unitParentId, year = NULL,
       
       colname <- paste0("attributeDescription_", x, sep = "")
       names(temp)[names(temp) == "attributeDescription"] <- colname
+      
+      colname <- paste0("measureUnitId_", x, sep = "")
+      names(temp)[names(temp) == "measureUnitId"] <- colname
+      
+      colname <- paste0("measureName_", x, sep = "")
+      names(temp)[names(temp) == "measureName"] <- colname
 
       colname <- paste0("val_", x, sep = "")
       names(temp)[names(temp) == "val"] <- colname
@@ -78,10 +85,16 @@ get_data_by_variable_locality <- function(varId, unitParentId, year = NULL,
     
     df <- lapply(varId, helper)
     df <- df[lengths(df) != 0]
-    df <- purrr::reduce(df, dplyr::left_join) %>%
-      select(one_of("id", "name", "year"), starts_with("val"), everything())
+    if(length(df) > 0){
+      df <- purrr::reduce(df, dplyr::left_join) 
+    } else {
+      stop("Filters returned empty set for every variable you provided.")
+    }
+    
   }
   
+  df <- df %>%
+    select(one_of("id", "name", "year"), starts_with("val"),starts_with("measure"), everything())
   
   df <- tibble::as_tibble(df)
   class(df) <- c("bdl", class(df))
